==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnToggledEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnToggledEventArgsDetailDescription, _super);
    function WebColumnToggledEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.k = null;
        _this.n = false;
        return _this;
    }
    WebColumnToggledEventArgsDetailDescription.prototype.get_type = function () {
        return "WebColumnToggledEventArgsDetail";
    };
    Object.defineProperty(WebColumnToggledEventArgsDetailDescription.prototype, "column", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("Column");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnToggledEventArgsDetailDescription.prototype, "checked", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Checked");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnToggledEventArgsDetailDescription.$t = markType(WebColumnToggledEventArgsDetailDescription, 'WebColumnToggledEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebColumnToggledEventArgsDetailDescription.__marshalByValue1 = true;
    WebColumnToggledEventArgsDetailDescription.__marshalByValueAlias1 = "ColumnToggledEventArgsDetail";
    return WebColumnToggledEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebColumnToggledEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnToggledEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnToggledEventArgsDetailDescription, _super);
    function WebColumnToggledEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.m = null;
        _this.p = false;
        return _this;
    }
    WebColumnToggledEventArgsDetailDescription.prototype.get_type = function () {
        return "WebColumnToggledEventArgsDetail";
    };
    Object.defineProperty(WebColumnToggledEventArgsDetailDescription.prototype, "column", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("Column");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnToggledEventArgsDetailDescription.prototype, "checked", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("Checked");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnToggledEventArgsDetailDescription.$t = markType(WebColumnToggledEventArgsDetailDescription, 'WebColumnToggledEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebColumnToggledEventArgsDetailDescription.__marshalByValue1 = true;
    WebColumnToggledEventArgsDetailDescription.__marshalByValueAlias1 = "ColumnToggledEventArgsDetail";
    return WebColumnToggledEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebColumnToggledEventArgsDetailDescription };
